pub enum Color {
Reset,
Rgb(RgbColor),
Named(NamedColor),
}Expand description
Text color
Variants
Reset
The default color for the text will be used, which varies by context (in some cases, it’s white; in others, it’s black; in still others, it is a shade of gray that isn’t normally used on text).
Rgb(RgbColor)
RGB Color
Named(NamedColor)
One of the 16 named Minecraft colors
Implementations
Sourceimpl Color
impl Color
pub const RESET: Color = Self::Reset
pub const AQUA: Color
pub const BLACK: Color
pub const BLUE: Color
pub const DARK_AQUA: Color
pub const DARK_BLUE: Color
pub const DARK_GRAY: Color
pub const DARK_GREEN: Color
pub const DARK_PURPLE: Color
pub const DARK_RED: Color
pub const GOLD: Color
pub const GRAY: Color
pub const GREEN: Color
pub const LIGHT_PURPLE: Color
pub const RED: Color
pub const WHITE: Color
pub const YELLOW: Color