pub struct ChunkView {
pub pos: ChunkPos,
/* private fields */
}Expand description
Represents the set of all chunk positions that a client can see, defined by
a center chunk position pos and view distance dist.
Fields
pos: ChunkPosThe center position of this chunk view.
Implementations
Sourceimpl ChunkView
impl ChunkView
Sourcepub const fn new(pos: ChunkPos, dist: u8) -> ChunkView
pub const fn new(pos: ChunkPos, dist: u8) -> ChunkView
Creates a new chunk view. dist is clamped to the range
0..MAX_VIEW_DIST.
pub const fn with_dist(self, dist: u8) -> ChunkView
pub const fn dist(self) -> u8
pub const fn contains(self, pos: ChunkPos) -> bool
Sourcepub fn iter(self) -> impl DoubleEndedIterator + ExactSizeIterator + Clone
pub fn iter(self) -> impl DoubleEndedIterator + ExactSizeIterator + Clone
Returns an iterator over all the chunk positions in this view. Positions
are sorted by the distance to pos in ascending order.
Sourcepub fn diff(self, other: ChunkView) -> impl DoubleEndedIterator + Clone
pub fn diff(self, other: ChunkView) -> impl DoubleEndedIterator + Clone
Returns an iterator over all the chunk positions in self, excluding
the positions that overlap with other. Positions are sorted by the
distance to pos in ascending order.
Sourcepub fn bounding_box(self) -> (ChunkPos, ChunkPos)
pub fn bounding_box(self) -> (ChunkPos, ChunkPos)
Returns a (min, max) tuple describing the tight axis-aligned bounding
box for this view. All chunk positions in the view are contained in the
bounding box.
Examples
use chunkedge_server::{ChunkPos, ChunkView};
let view = ChunkView::new(ChunkPos::new(5, -4), 16);
let (min, max) = view.bounding_box();
for pos in view.iter() {
assert!(pos.x >= min.x && pos.x <= max.x && pos.z >= min.z && pos.z <= max.z);
}Trait Implementations
impl Copy for ChunkView
impl Eq for ChunkView
impl StructuralPartialEq for ChunkView