pub struct ClientSpawnQuery {
pub is_hardcore: &'static mut IsHardcore,
pub game_mode: &'static mut GameMode,
pub prev_game_mode: &'static mut PrevGameMode,
pub hashed_seed: &'static mut HashedSeed,
pub view_distance: &'static mut ViewDistance,
pub reduced_debug_info: &'static mut ReducedDebugInfo,
pub has_respawn_screen: &'static mut HasRespawnScreen,
pub is_debug: &'static mut IsDebug,
pub is_flat: &'static mut IsFlat,
pub death_loc: &'static mut DeathLocation,
pub portal_cooldown: &'static mut PortalCooldown,
}Expand description
A convenient QueryData for obtaining client spawn components. Also see
ClientSpawnQueryReadOnly.
Fields
is_hardcore: &'static mut IsHardcoregame_mode: &'static mut GameModeprev_game_mode: &'static mut PrevGameModehashed_seed: &'static mut HashedSeedview_distance: &'static mut ViewDistancereduced_debug_info: &'static mut ReducedDebugInfohas_respawn_screen: &'static mut HasRespawnScreenis_debug: &'static mut IsDebugis_flat: &'static mut IsFlatdeath_loc: &'static mut DeathLocationportal_cooldown: &'static mut PortalCooldownTrait Implementations
Sourceimpl QueryData for ClientSpawnQuery
SAFETY: we assert fields are readonly below
impl QueryData for ClientSpawnQuery
SAFETY: we assert fields are readonly below
Sourcetype ReadOnly = ClientSpawnQueryReadOnly
type ReadOnly = ClientSpawnQueryReadOnly
The read-only variant of this
QueryData, which satisfies the ReadOnlyQueryData trait.Sourceimpl WorldQuery for ClientSpawnQuery
impl WorldQuery for ClientSpawnQuery
Sourceunsafe fn set_archetype<'__w>(
_fetch: &mut <ClientSpawnQuery as WorldQuery>::Fetch<'__w>,
_state: &<ClientSpawnQuery as WorldQuery>::State,
_archetype: &'__w Archetype,
_table: &'__w Table,
)
unsafe fn set_archetype<'__w>( _fetch: &mut <ClientSpawnQuery as WorldQuery>::Fetch<'__w>, _state: &<ClientSpawnQuery as WorldQuery>::State, _archetype: &'__w Archetype, _table: &'__w Table, )
SAFETY: we call set_archetype for each member that implements Fetch
Sourceunsafe fn set_table<'__w>(
_fetch: &mut <ClientSpawnQuery as WorldQuery>::Fetch<'__w>,
_state: &<ClientSpawnQuery as WorldQuery>::State,
_table: &'__w Table,
)
unsafe fn set_table<'__w>( _fetch: &mut <ClientSpawnQuery as WorldQuery>::Fetch<'__w>, _state: &<ClientSpawnQuery as WorldQuery>::State, _table: &'__w Table, )
SAFETY: we call set_table for each member that implements Fetch
Sourceunsafe fn fetch<'__w>(
_fetch: &mut <ClientSpawnQuery as WorldQuery>::Fetch<'__w>,
_entity: Entity,
_table_row: TableRow,
) -> <ClientSpawnQuery as WorldQuery>::Item<'__w>
unsafe fn fetch<'__w>( _fetch: &mut <ClientSpawnQuery as WorldQuery>::Fetch<'__w>, _entity: Entity, _table_row: TableRow, ) -> <ClientSpawnQuery as WorldQuery>::Item<'__w>
SAFETY: we call fetch for each member that implements Fetch.
Sourceconst IS_DENSE: bool = true
const IS_DENSE: bool = true
Returns true if (and only if) every table of every archetype matched by this fetch contains
all of the matched components. This is used to select a more efficient “table iterator”
for “dense” queries. If this returns true,
WorldQuery::set_table must be used before
WorldQuery::fetch can be called for iterators. If this returns false,
WorldQuery::set_archetype must be used before WorldQuery::fetch can be called for
iterators.Sourcetype Item<'__w> = ClientSpawnQueryItem<'__w>
type Item<'__w> = ClientSpawnQueryItem<'__w>
The item returned by this
WorldQuery
For QueryData this will be the item returned by the query.
For QueryFilter this will be either (), or a bool indicating whether the entity should be included
or a tuple of such things.Sourcetype Fetch<'__w> = ClientSpawnQueryFetch<'__w>
type Fetch<'__w> = ClientSpawnQueryFetch<'__w>
Per archetype/table state used by this
WorldQuery to fetch Self::ItemSourcetype State = ClientSpawnQueryState
type State = ClientSpawnQueryState
State used to construct a
Self::Fetch. This will be cached inside QueryState,
so it is best to move as much data / computation here as possible to reduce the cost of
constructing Self::Fetch.Sourcefn shrink<'__wlong, '__wshort>(
item: <ClientSpawnQuery as WorldQuery>::Item<'__wlong>,
) -> <ClientSpawnQuery as WorldQuery>::Item<'__wshort>where
'__wlong: '__wshort,
fn shrink<'__wlong, '__wshort>(
item: <ClientSpawnQuery as WorldQuery>::Item<'__wlong>,
) -> <ClientSpawnQuery as WorldQuery>::Item<'__wshort>where
'__wlong: '__wshort,
This function manually implements subtyping for the query items.
Sourceunsafe fn init_fetch<'__w>(
_world: UnsafeWorldCell<'__w>,
state: &<ClientSpawnQuery as WorldQuery>::State,
_last_run: Tick,
_this_run: Tick,
) -> <ClientSpawnQuery as WorldQuery>::Fetch<'__w>
unsafe fn init_fetch<'__w>( _world: UnsafeWorldCell<'__w>, state: &<ClientSpawnQuery as WorldQuery>::State, _last_run: Tick, _this_run: Tick, ) -> <ClientSpawnQuery as WorldQuery>::Fetch<'__w>
Creates a new instance of this fetch. Read more
Sourcefn update_component_access(
state: &<ClientSpawnQuery as WorldQuery>::State,
_access: &mut FilteredAccess<ComponentId>,
)
fn update_component_access( state: &<ClientSpawnQuery as WorldQuery>::State, _access: &mut FilteredAccess<ComponentId>, )
Sourcefn init_state(world: &mut World) -> ClientSpawnQueryState
fn init_state(world: &mut World) -> ClientSpawnQueryState
Creates and initializes a
State for this WorldQuery type.Sourcefn get_state(components: &Components) -> Option<ClientSpawnQueryState>
fn get_state(components: &Components) -> Option<ClientSpawnQueryState>
Sourcefn matches_component_set(
state: &<ClientSpawnQuery as WorldQuery>::State,
_set_contains_id: &impl Fn(ComponentId) -> bool,
) -> bool
fn matches_component_set( state: &<ClientSpawnQuery as WorldQuery>::State, _set_contains_id: &impl Fn(ComponentId) -> bool, ) -> bool
fn set_access(_state: &mut Self::State, _access: &FilteredAccess<ComponentId>)
fn set_access(_state: &mut Self::State, _access: &FilteredAccess<ComponentId>)
Sets available accesses for implementors with dynamic access such as
FilteredEntityRef
or FilteredEntityMut. Read moreAuto Trait Implementations
impl Freeze for ClientSpawnQuery
impl RefUnwindSafe for ClientSpawnQuery
impl Send for ClientSpawnQuery
impl Sync for ClientSpawnQuery
impl Unpin for ClientSpawnQuery
impl !UnwindSafe for ClientSpawnQuery