pub struct Equipment { /* private fields */ }Expand description
Contains the visible equipment of a LivingEntity, such as armor and held
items. By default this is not synced with a player’s
chunkedge_inventory::Inventory, so the armor the player has equipped in
their inventory, will not be visible by other players. You would have to
change the equipment in this component here or attach the
EquipmentInventorySync component to the player entity to sync the
equipment with the inventory.
Implementations
Sourceimpl Equipment
impl Equipment
pub const SLOT_COUNT: usize = 8usize
pub fn new( main_hand: ItemStack, off_hand: ItemStack, boots: ItemStack, leggings: ItemStack, chestplate: ItemStack, helmet: ItemStack, body: ItemStack, saddle: ItemStack, ) -> Equipment
pub fn new_empty() -> Equipment
pub fn slot(&self, idx: EquipmentSlot) -> &ItemStack
pub fn set_slot(&mut self, idx: EquipmentSlot, item: ItemStack)
pub fn main_hand(&self) -> &ItemStack
pub fn off_hand(&self) -> &ItemStack
pub fn feet(&self) -> &ItemStack
pub fn legs(&self) -> &ItemStack
pub fn chest(&self) -> &ItemStack
pub fn head(&self) -> &ItemStack
pub fn body(&self) -> &ItemStack
pub fn saddle(&self) -> &ItemStack
pub fn set_main_hand(&mut self, item: ItemStack)
pub fn set_off_hand(&mut self, item: ItemStack)
pub fn set_feet(&mut self, item: ItemStack)
pub fn set_legs(&mut self, item: ItemStack)
pub fn set_chest(&mut self, item: ItemStack)
pub fn set_head(&mut self, item: ItemStack)
pub fn set_body(&mut self, item: ItemStack)
pub fn set_saddle(&mut self, item: ItemStack)
pub fn clear(&mut self)
pub fn is_default(&self) -> bool