pub struct HitboxShape(pub Aabb);Expand description
Size of hitbox. The only way to manipulate it without losing it on the next tick is using a marker entity. Marker entity’s hitbox is never updated.
Tuple Fields
0: AabbImplementations
Sourceimpl HitboxShape
impl HitboxShape