pub struct View {
pub pos: &'static Position,
pub view_dist: &'static ViewDistance,
}Fields
pos: &'static Positionview_dist: &'static ViewDistanceTrait Implementations
Sourceimpl WorldQuery for View
impl WorldQuery for View
Sourceunsafe fn set_archetype<'__w>(
_fetch: &mut <View as WorldQuery>::Fetch<'__w>,
_state: &<View as WorldQuery>::State,
_archetype: &'__w Archetype,
_table: &'__w Table,
)
unsafe fn set_archetype<'__w>( _fetch: &mut <View as WorldQuery>::Fetch<'__w>, _state: &<View as WorldQuery>::State, _archetype: &'__w Archetype, _table: &'__w Table, )
SAFETY: we call set_archetype for each member that implements Fetch
Sourceunsafe fn set_table<'__w>(
_fetch: &mut <View as WorldQuery>::Fetch<'__w>,
_state: &<View as WorldQuery>::State,
_table: &'__w Table,
)
unsafe fn set_table<'__w>( _fetch: &mut <View as WorldQuery>::Fetch<'__w>, _state: &<View as WorldQuery>::State, _table: &'__w Table, )
SAFETY: we call set_table for each member that implements Fetch
Sourceunsafe fn fetch<'__w>(
_fetch: &mut <View as WorldQuery>::Fetch<'__w>,
_entity: Entity,
_table_row: TableRow,
) -> <View as WorldQuery>::Item<'__w>
unsafe fn fetch<'__w>( _fetch: &mut <View as WorldQuery>::Fetch<'__w>, _entity: Entity, _table_row: TableRow, ) -> <View as WorldQuery>::Item<'__w>
SAFETY: we call fetch for each member that implements Fetch.
Sourceconst IS_DENSE: bool = true
const IS_DENSE: bool = true
Returns true if (and only if) every table of every archetype matched by this fetch contains
all of the matched components. This is used to select a more efficient “table iterator”
for “dense” queries. If this returns true,
WorldQuery::set_table must be used before
WorldQuery::fetch can be called for iterators. If this returns false,
WorldQuery::set_archetype must be used before WorldQuery::fetch can be called for
iterators.Sourcetype Item<'__w> = ViewItem<'__w>
type Item<'__w> = ViewItem<'__w>
The item returned by this
WorldQuery
For QueryData this will be the item returned by the query.
For QueryFilter this will be either (), or a bool indicating whether the entity should be included
or a tuple of such things.Sourcetype Fetch<'__w> = ViewFetch<'__w>
type Fetch<'__w> = ViewFetch<'__w>
Per archetype/table state used by this
WorldQuery to fetch Self::ItemSourcetype State = ViewState
type State = ViewState
State used to construct a
Self::Fetch. This will be cached inside QueryState,
so it is best to move as much data / computation here as possible to reduce the cost of
constructing Self::Fetch.Sourcefn shrink<'__wlong, '__wshort>(
item: <View as WorldQuery>::Item<'__wlong>,
) -> <View as WorldQuery>::Item<'__wshort>where
'__wlong: '__wshort,
fn shrink<'__wlong, '__wshort>(
item: <View as WorldQuery>::Item<'__wlong>,
) -> <View as WorldQuery>::Item<'__wshort>where
'__wlong: '__wshort,
This function manually implements subtyping for the query items.
Sourceunsafe fn init_fetch<'__w>(
_world: UnsafeWorldCell<'__w>,
state: &<View as WorldQuery>::State,
_last_run: Tick,
_this_run: Tick,
) -> <View as WorldQuery>::Fetch<'__w>
unsafe fn init_fetch<'__w>( _world: UnsafeWorldCell<'__w>, state: &<View as WorldQuery>::State, _last_run: Tick, _this_run: Tick, ) -> <View as WorldQuery>::Fetch<'__w>
Creates a new instance of this fetch. Read more
Sourcefn update_component_access(
state: &<View as WorldQuery>::State,
_access: &mut FilteredAccess<ComponentId>,
)
fn update_component_access( state: &<View as WorldQuery>::State, _access: &mut FilteredAccess<ComponentId>, )
Sourcefn init_state(world: &mut World) -> ViewState
fn init_state(world: &mut World) -> ViewState
Creates and initializes a
State for this WorldQuery type.Sourcefn get_state(components: &Components) -> Option<ViewState>
fn get_state(components: &Components) -> Option<ViewState>
Sourcefn matches_component_set(
state: &<View as WorldQuery>::State,
_set_contains_id: &impl Fn(ComponentId) -> bool,
) -> bool
fn matches_component_set( state: &<View as WorldQuery>::State, _set_contains_id: &impl Fn(ComponentId) -> bool, ) -> bool
fn set_access(_state: &mut Self::State, _access: &FilteredAccess<ComponentId>)
fn set_access(_state: &mut Self::State, _access: &FilteredAccess<ComponentId>)
Sets available accesses for implementors with dynamic access such as
FilteredEntityRef
or FilteredEntityMut. Read moreimpl Copy for View
impl ReadOnlyQueryData for View
SAFETY: we assert fields are readonly below