Plugin

Trait Plugin 

pub trait Plugin:
    Downcast
    + Any
    + Send
    + Sync {
    // Required method
    fn build(&self, app: &mut App);

    // Provided methods
    fn ready(&self, _app: &App) -> bool { ... }
    fn finish(&self, _app: &mut App) { ... }
    fn cleanup(&self, _app: &mut App) { ... }
    fn name(&self) -> &str { ... }
    fn is_unique(&self) -> bool { ... }
}
A collection of Bevy app logic and configuration.

Plugins configure an App. When an App registers a plugin, the plugin’s Plugin::build function is run. By default, a plugin can only be added once to an App.

If the plugin may need to be added twice or more, the function is_unique() should be overridden to return false. Plugins are considered duplicate if they have the same name(). The default name() implementation returns the type name, which means generic plugins with different type parameters will not be considered duplicates.

Lifecycle of a plugin

When adding a plugin to an App:

Defining a plugin.

Most plugins are simply functions that add configuration to an App.

App::new().add_plugins(my_plugin).run();

// This function implements `Plugin`, along with every other `fn(&mut App)`.
pub fn my_plugin(app: &mut App) {
    app.add_systems(Update, hello_world);
}

For more advanced use cases, the Plugin trait can be implemented manually for a type.

pub struct AccessibilityPlugin {
    pub flicker_damping: bool,
    // ...
}

impl Plugin for AccessibilityPlugin {
    fn build(&self, app: &mut App) {
        if self.flicker_damping {
            app.add_systems(PostUpdate, damp_flickering);
        }
    }
}

Required Methods

fn build(&self, app: &mut App)

Configures the App to which this plugin is added.

Provided Methods

fn ready(&self, _app: &App) -> bool

Has the plugin finished its setup? This can be useful for plugins that need something asynchronous to happen before they can finish their setup, like the initialization of a renderer. Once the plugin is ready, finish should be called.

fn finish(&self, _app: &mut App)

Finish adding this plugin to the App, once all plugins registered are ready. This can be useful for plugins that depends on another plugin asynchronous setup, like the renderer.

fn cleanup(&self, _app: &mut App)

Runs after all plugins are built and finished, but before the app schedule is executed. This can be useful if you have some resource that other plugins need during their build step, but after build you want to remove it and send it to another thread.

fn name(&self) -> &str

Configures a name for the Plugin which is primarily used for checking plugin uniqueness and debugging.

fn is_unique(&self) -> bool

If the plugin can be meaningfully instantiated several times in an App, override this method to return false.

Implementations



impl dyn Plugin

pub fn is<__T>(&self) -> bool
where __T: Plugin,

Returns true if the trait object wraps an object of type __T.

pub fn downcast<__T>(self: Box<dyn Plugin>) -> Result<Box<__T>, Box<dyn Plugin>>
where __T: Plugin,

Returns a boxed object from a boxed trait object if the underlying object is of type __T. Returns the original boxed trait if it isn’t.

pub fn downcast_rc<__T>(self: Rc<dyn Plugin>) -> Result<Rc<__T>, Rc<dyn Plugin>>
where __T: Plugin,

Returns an Rc-ed object from an Rc-ed trait object if the underlying object is of type __T. Returns the original Rc-ed trait if it isn’t.

pub fn downcast_ref<__T>(&self) -> Option<&__T>
where __T: Plugin,

Returns a reference to the object within the trait object if it is of type __T, or None if it isn’t.

pub fn downcast_mut<__T>(&mut self) -> Option<&mut __T>
where __T: Plugin,

Returns a mutable reference to the object within the trait object if it is of type __T, or None if it isn’t.

Implementations on Foreign Types

Source

impl Plugin for AdvancementPlugin

Source

fn build(&self, app: &mut App)

Source

impl Plugin for AnvilPlugin

Source

fn build(&self, app: &mut App)

Source

impl Plugin for BossBarPlugin

Source

fn build(&self, app: &mut App)

Source

impl Plugin for CommandPlugin

Source

fn build(&self, app: &mut App)

Source

impl Plugin for CommandScopePlugin

Source

fn build(&self, app: &mut App)

Source

impl Plugin for EquipmentPlugin

Source

fn build(&self, app: &mut App)

Source

impl Plugin for InventoryPlugin

Source

fn build(&self, app: &mut App)

Source

impl Plugin for NetworkPlugin

Source

fn build(&self, app: &mut App)

Source

impl Plugin for PlayerListPlugin

Source

fn build(&self, app: &mut App)

Source

impl Plugin for ScoreboardPlugin

Source

fn build(&self, app: &mut App)

Source

impl Plugin for WeatherPlugin

Source

fn build(&self, app: &mut App)

Source

impl Plugin for WorldBorderPlugin

Source

fn build(&self, app: &mut App)



impl Plugin for LogPlugin



fn build(&self, app: &mut App)

Source

impl<T> Plugin for CommandHandlerPlugin<T>
where T: Command + Send + Sync + 'static,

Source

fn build(&self, app: &mut App)

Implementors

Source

impl Plugin for AbilitiesPlugin

Source

impl Plugin for ActionPlugin



impl Plugin for MainSchedulePlugin



impl Plugin for PanicHandlerPlugin



impl Plugin for ScheduleRunnerPlugin



impl Plugin for TerminalCtrlCHandlerPlugin

Source

impl Plugin for ClientPlugin

Source

impl Plugin for ClientCommandPlugin

Source

impl Plugin for ClientSettingsPlugin

Source

impl Plugin for CustomPayloadPlugin

Source

impl Plugin for HitboxPlugin

Source

impl Plugin for EntityPlugin

Source

impl Plugin for EventLoopPlugin

Source

impl Plugin for HandSwingPlugin

Source

impl Plugin for InteractBlockPlugin

Source

impl Plugin for InteractEntityPlugin

Source

impl Plugin for InteractItemPlugin

Source

impl Plugin for KeepalivePlugin

Source

impl Plugin for LayerPlugin

Source

impl Plugin for MessagePlugin

Source

impl Plugin for MovementPlugin

Source

impl Plugin for OpLevelPlugin

Source

impl Plugin for PassengerPlugin

Source

impl Plugin for BiomePlugin

Source

impl Plugin for DimensionTypePlugin

Source

impl Plugin for RegistryPlugin

Source

impl Plugin for ResourcePackPlugin

Source

impl Plugin for StatusPlugin

Source

impl Plugin for StatusEffectPlugin

Source

impl Plugin for ServerPlugin

Source

impl Plugin for TeleportPlugin



impl Plugin for TaskPoolPlugin



impl<C> Plugin for ValidateParentHasComponentPlugin<C>
where C: Component,



impl<C, F, R> Plugin for HierarchyPropagatePlugin<C, F, R>
where C: Component + Clone + PartialEq, F: QueryFilter + 'static, R: Relationship,



impl<T> Plugin for T
where T: Fn(&mut App) + Send + Sync + 'static,