pub struct NetworkSettings {
pub callbacks: ErasedNetworkCallbacks,
pub tokio_handle: Option<Handle>,
pub max_connections: usize,
pub max_players: usize,
pub address: SocketAddr,
pub connection_mode: ConnectionMode,
pub incoming_byte_limit: usize,
pub outgoing_byte_limit: usize,
}Expand description
Settings for NetworkPlugin. Note that mutations to these fields have no
effect after the plugin is built.
Fields
callbacks: ErasedNetworkCallbackstokio_handle: Option<Handle>The [Handle] to the tokio runtime the server will use. If None is
provided, the server will create its own tokio runtime at startup.
Default Value
None
max_connections: usizeThe maximum number of simultaneous initial connections to the server.
This only considers the connections before the play state where the client is spawned into the world..
Default Value
The default value is left unspecified and may change in future versions.
max_players: usizeDefault Value
20
address: SocketAddrThe socket address the server will be bound to.
Default Value
0.0.0.0:25565, which will listen on every available network interface.
connection_mode: ConnectionModeThe connection mode. This determines if client authentication and encryption should take place and if the server should get the player data from a proxy.
NOTE: Mutations to this field have no effect if
Default Value
incoming_byte_limit: usizeThe maximum capacity (in bytes) of the buffer used to hold incoming packet data.
A larger capacity reduces the chance that a client needs to be disconnected due to a full buffer, but increases potential memory usage.
Default Value
The default value is left unspecified and may change in future versions.
outgoing_byte_limit: usizeThe maximum capacity (in bytes) of the buffer used to hold outgoing packet data.
A larger capacity reduces the chance that a client needs to be disconnected due to a full buffer, but increases potential memory usage.
Default Value
The default value is left unspecified and may change in future versions.